# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class StoredPaymentSourcePaymentType(object):

    """Implementation of the 'Stored Payment Source Payment Type' enum.

    Indicates the type of the stored payment_source payment.

    Attributes:
        ONE_TIME: One Time payment such as online purchase or donation. (e.g.
            Checkout with one-click).
        RECURRING: Payment which is part of a series of payments with fixed or
            variable amounts, following a fixed time interval. (e.g.
            Subscription payments).
        UNSCHEDULED: Payment which is part of a series of payments that occur
            on a non-fixed schedule and/or have variable amounts. (e.g.
            Account Topup payments).

    """
    ONE_TIME = 'ONE_TIME'

    RECURRING = 'RECURRING'

    UNSCHEDULED = 'UNSCHEDULED'

