# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PayeePaymentMethodPreference(object):

    """Implementation of the 'Payee Payment Method Preference' enum.

    The merchant-preferred payment methods.

    Attributes:
        UNRESTRICTED: Accepts any type of payment from the customer.
        IMMEDIATE_PAYMENT_REQUIRED: Accepts only immediate payment from the
            customer. For example, credit card, PayPal balance, or instant
            ACH. Ensures that at the time of capture, the payment does not
            have the `pending` status.

    """
    UNRESTRICTED = 'UNRESTRICTED'

    IMMEDIATE_PAYMENT_REQUIRED = 'IMMEDIATE_PAYMENT_REQUIRED'

