# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class ExperienceStatus(object):

    """Implementation of the 'Experience Status' enum.

    This field indicates the status of PayPal's Checkout experience throughout
    the order lifecycle. The values reflect the current stage of the checkout
    process.

    Attributes:
        NOT_STARTED: PayPal checkout process has not yet begun.
        IN_PROGRESS: PayPal checkout initiated. User is on the checkout page
            for order review before approval.
        CANCELED: PayPal checkout is canceled (by closing the checkout window
            or clicking cancel) before the order approval.
        APPROVED: Order is approved. User has completed the checkout process.

    """
    NOT_STARTED = 'NOT_STARTED'

    IN_PROGRESS = 'IN_PROGRESS'

    CANCELED = 'CANCELED'

    APPROVED = 'APPROVED'

