# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class EnrollmentStatus(object):

    """Implementation of the 'Enrollment Status' enum.

    Status of Authentication eligibility.

    Attributes:
        ENROLLED: Yes. The bank is participating in 3-D Secure protocol and
            will return the ACSUrl.
        NOTENROLLED: No. The bank is not participating in 3-D Secure protocol.
        UNAVAILABLE: Unavailable. The DS or ACS is not available for
            authentication at the time of the request.
        BYPASS: Bypass. The merchant authentication rule is triggered to
            bypass authentication.

    """
    ENROLLED = 'Y'

    NOTENROLLED = 'N'

    UNAVAILABLE = 'U'

    BYPASS = 'B'

