# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class DisbursementMode(object):

    """Implementation of the 'Disbursement Mode' enum.

    The funds that are held on behalf of the merchant.

    Attributes:
        INSTANT: The funds are released to the merchant immediately.
        DELAYED: The funds are held for a finite number of days. The actual
            duration depends on the region and type of integration. You can
            release the funds through a referenced payout. Otherwise, the
            funds disbursed automatically after the specified duration.

    """
    INSTANT = 'INSTANT'

    DELAYED = 'DELAYED'

