# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class SubscriptionPricingModel(object):

    """Implementation of the 'Subscription Pricing Model' enum.

    The pricing model for tiered plan. The `tiers` parameter is required.

    Attributes:
        VOLUME: A volume pricing model.
        TIERED: A tiered pricing model.

    """
    VOLUME = 'VOLUME'

    TIERED = 'TIERED'

