# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class ItemCategory(object):

    """Implementation of the 'Item Category' enum.

    The item category type.

    Attributes:
        DIGITAL_GOODS: Goods that are stored, delivered, and used in their
            electronic format. This value is not currently supported for API
            callers that leverage the PayPal for Commerce Platform product.
        PHYSICAL_GOODS: A tangible item that can be shipped with proof of
            delivery.
        DONATION: A contribution or gift for which no good or service is
            exchanged, usually to a not for profit organization.

    """
    DIGITAL_GOODS = 'DIGITAL_GOODS'

    PHYSICAL_GOODS = 'PHYSICAL_GOODS'

    DONATION = 'DONATION'

