# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PricingModel(object):

    """Implementation of the 'Pricing Model' enum.

    The pricing model for the billing cycle.

    Attributes:
        FIXED: A fixed pricing scheme where the customer is charged a fixed
            amount.
        VARIABLE: A variable pricing scheme where the customer is charged a
            variable amount.
        AUTO_RELOAD: A auto-reload pricing scheme where the customer is
            charged a fixed amount for reload.

    """
    FIXED = 'FIXED'

    VARIABLE = 'VARIABLE'

    AUTO_RELOAD = 'AUTO_RELOAD'

