# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PaResStatus(object):

    """Implementation of the 'PARes Status' enum.

    Transactions status result identifier. The outcome of the issuer's
    authentication.

    Attributes:
        SUCCESSFULAUTHENTICATION: Successful authentication.
        FAILEDAUTHENTICATION: Failed authentication / account not verified /
            transaction denied.
        UNABLETOCOMPLETEAUTHENTICATION: Unable to complete authentication.
        SUCCESSFULATTEMPTSTRANSACTION: Successful attempts transaction.
        CHALLENGEREQUIRED: Challenge required for authentication.
        AUTHENTICATIONREJECTED: Authentication rejected (merchant must not
            submit for authorization).
        DECOUPLEDAUTHENTICATION: Challenge required; decoupled authentication
            confirmed.
        INFORMATIONALONLY: Informational only; 3DS requestor challenge
            preference acknowledged.

    """
    SUCCESSFULAUTHENTICATION = 'Y'

    FAILEDAUTHENTICATION = 'N'

    UNABLETOCOMPLETEAUTHENTICATION = 'U'

    SUCCESSFULATTEMPTSTRANSACTION = 'A'

    CHALLENGEREQUIRED = 'C'

    AUTHENTICATIONREJECTED = 'R'

    DECOUPLEDAUTHENTICATION = 'D'

    INFORMATIONALONLY = 'I'

