# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class SubscriptionsCardBrand(object):

    """Implementation of the 'Subscriptions Card Brand' enum.

    The card network or brand. Applies to credit, debit, gift, and payment
    cards.

    Attributes:
        VISA: Visa card.
        MASTERCARD: Mastercard card.
        DISCOVER: Discover card.
        AMEX: American Express card.
        SOLO: Solo debit card.
        JCB: Japan Credit Bureau card.
        STAR: Military Star card.
        DELTA: Delta Airlines card.
        SWITCH: Switch credit card.
        MAESTRO: Maestro credit card.
        CB_NATIONALE: Carte Bancaire (CB) credit card.
        CONFIGOGA: Configoga credit card.
        CONFIDIS: Confidis credit card.
        ELECTRON: Visa Electron credit card.
        CETELEM: Cetelem credit card.
        CHINA_UNION_PAY: China union pay credit card.
        DINERS: The Diners Club International banking and payment services
            capability network owned by Discover Financial Services (DFS), one
            of the most recognized brands in US financial services.
        ELO: The Brazilian Elo card payment network.
        HIPER: The Hiper - Ingenico ePayment network.
        HIPERCARD: The Brazilian Hipercard payment network that's widely
            accepted in the retail market.
        RUPAY: The RuPay payment network.
        GE: The GE Credit Union 3Point card payment network.
        SYNCHRONY: The Synchrony Financial (SYF) payment network.
        EFTPOS: The Electronic Fund Transfer At Point of Sale(EFTPOS) Debit
            card payment network.
        UNKNOWN: UNKNOWN payment network.

    """
    VISA = 'VISA'

    MASTERCARD = 'MASTERCARD'

    DISCOVER = 'DISCOVER'

    AMEX = 'AMEX'

    SOLO = 'SOLO'

    JCB = 'JCB'

    STAR = 'STAR'

    DELTA = 'DELTA'

    SWITCH = 'SWITCH'

    MAESTRO = 'MAESTRO'

    CB_NATIONALE = 'CB_NATIONALE'

    CONFIGOGA = 'CONFIGOGA'

    CONFIDIS = 'CONFIDIS'

    ELECTRON = 'ELECTRON'

    CETELEM = 'CETELEM'

    CHINA_UNION_PAY = 'CHINA_UNION_PAY'

    DINERS = 'DINERS'

    ELO = 'ELO'

    HIPER = 'HIPER'

    HIPERCARD = 'HIPERCARD'

    RUPAY = 'RUPAY'

    GE = 'GE'

    SYNCHRONY = 'SYNCHRONY'

    EFTPOS = 'EFTPOS'

    UNKNOWN = 'UNKNOWN'

