# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class VaultTokenRequestType(object):

    """Implementation of the 'Vault Token Request Type' enum.

    The tokenization method that generated the ID.

    Attributes:
        SETUP_TOKEN: The setup token, which is a temporary reference to
            payment source.

    """
    SETUP_TOKEN = 'SETUP_TOKEN'

