# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PaypalPaymentTokenCustomerType(object):

    """Implementation of the 'PayPal Payment Token Customer Type' enum.

    The customer type associated with the PayPal payment token. This is to
    indicate whether the customer acting on the merchant / platform is either
    a business or a consumer., The customer type associated with a digital
    wallet payment token. This is to indicate whether the customer acting on
    the merchant / platform is either a business or a consumer.

    Attributes:
        CONSUMER: The customer vaulting the PayPal payment token is a consumer
            on the merchant / platform.
        BUSINESS: The customer vaulting the PayPal payment token is a business
            on merchant / platform.

    """
    CONSUMER = 'CONSUMER'

    BUSINESS = 'BUSINESS'

