# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class VenmoWalletExperienceContextShippingPreference(object):

    """Implementation of the 'Venmo Wallet Experience Context Shipping Preference' enum.

    The location from which the shipping address is derived.

    Attributes:
        GET_FROM_FILE: Get the customer-provided shipping address on the
            PayPal site.
        NO_SHIPPING: Redacts the shipping address from the PayPal site.
            Recommended for digital goods.
        SET_PROVIDED_ADDRESS: Get the merchant-provided address. The customer
            cannot change this address on the PayPal site. If merchant does
            not pass an address, customer can choose the address on PayPal
            pages.

    """
    GET_FROM_FILE = 'GET_FROM_FILE'

    NO_SHIPPING = 'NO_SHIPPING'

    SET_PROVIDED_ADDRESS = 'SET_PROVIDED_ADDRESS'

