# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class OsType(object):

    """Implementation of the 'OS Type' enum.

    Operating System type of the device that the buyer is using.

    Attributes:
        ANDROID: Google Android OS.
        IOS: Apple OS typically found in Apple mobile devices.
        OTHER: Any other OS type.

    """
    ANDROID = 'ANDROID'

    IOS = 'IOS'

    OTHER = 'OTHER'

