# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class VenmoWalletExperienceContextUserAction(object):

    """Implementation of the 'Venmo Wallet Experience Context User Action' enum.

    Configures a Continue or Pay Now checkout flow.

    Attributes:
        CONTINUE: After you redirect the customer to the Venmo payment page, a
            Continue button appears. Use this option when the final amount is
            not known when the checkout flow is initiated and you want to
            redirect the customer to the merchant page without processing the
            payment.
        PAY_NOW: After you redirect the customer to the Venmo payment page, a
            Pay Now button appears. Use this option when the final amount is
            known when the checkout is initiated and you want to process the
            payment immediately when the customer clicks Pay Now.

    """
    CONTINUE = 'CONTINUE'

    PAY_NOW = 'PAY_NOW'

