# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PaypalWalletAccountVerificationStatus(object):

    """Implementation of the 'PayPal Wallet Account Verification Status' enum.

    The account status indicates whether the buyer has verified the financial
    details associated with their PayPal account.

    Attributes:
        VERIFIED: The buyer has completed the verification of the financial
            details associated with this PayPal account. For example:
            confirming their bank account.
        UNVERIFIED: The buyer has not completed the verification of the
            financial details associated with this PayPal account. For
            example: confirming their bank account.

    """
    VERIFIED = 'VERIFIED'

    UNVERIFIED = 'UNVERIFIED'

