# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class SetupFeeFailureAction(object):

    """Implementation of the 'Setup Fee Failure Action' enum.

    The action to take on the subscription if the initial payment for the
    setup fails.

    Attributes:
        CONTINUE: Continues the subscription if the initial payment for the
            setup fails.
        CANCEL: Cancels the subscription if the initial payment for the setup
            fails.

    """
    CONTINUE = 'CONTINUE'

    CANCEL = 'CANCEL'

