# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class ReturnFlow(object):

    """Implementation of the 'Return Flow' enum.

    Merchant preference on how the buyer can navigate back to merchant website
    post approving the transaction on the Venmo App.

    Attributes:
        AUTO: After payment approval in the PayPal App, buyer will
            automatically be redirected to the merchant website.
        MANUAL: After payment approval in the PayPal App, buyer will be asked
            to manually navigate back to the merchant website where they
            started the transaction from. The buyer is shown a message like
            'Return to Merchant' to return to the source where the transaction
            actually started.

    """
    AUTO = 'AUTO'

    MANUAL = 'MANUAL'

