# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class CardVerificationStatus(object):

    """Implementation of the 'Card Verification Status' enum.

    Verification status of Card.

    Attributes:
        VERIFIED: Card has been verified
        FAILED: Card verification has failed

    """
    VERIFIED = 'VERIFIED'

    FAILED = 'FAILED'

