# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PaypalWalletVaultStatus(object):

    """Implementation of the 'PayPal Wallet Vault Status' enum.

    The vault status.

    Attributes:
        VAULTED: The payment source has been saved in your customer's vault.
            This vault status reflects `/v3/vault` status.
        CREATED: DEPRECATED. The payment source has been saved in your
            customer's vault. This status applies to deprecated integration
            patterns and will not be returned for v3/vault integrations.
        APPROVED: Customer has approved the action of saving the specified
            payment_source into their vault. Use v3/vault/payment-tokens with
            given setup_token to save the payment source in the vault

    """
    VAULTED = 'VAULTED'

    CREATED = 'CREATED'

    APPROVED = 'APPROVED'

