# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class TokenType(object):

    """Implementation of the 'Token Type' enum.

    The tokenization method that generated the ID.

    Attributes:
        BILLING_AGREEMENT: The PayPal billing agreement ID. References an
            approved recurring payment for goods or services.

    """
    BILLING_AGREEMENT = 'BILLING_AGREEMENT'

