# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PaypalReferenceIdType(object):

    """Implementation of the 'PayPal Reference Id Type' enum.

    The PayPal reference ID type.

    Attributes:
        ODR: An order ID.
        TXN: A transaction ID.
        SUB: A subscription ID.
        PAP: A pre-approved payment ID.

    """
    ODR = 'ODR'

    TXN = 'TXN'

    SUB = 'SUB'

    PAP = 'PAP'

