# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class CardType(object):

    """Implementation of the 'Card Type' enum.

    Type of card. i.e Credit, Debit and so on.

    Attributes:
        CREDIT: A credit card.
        DEBIT: A debit card.
        PREPAID: A Prepaid card.
        STORE: A store card.
        UNKNOWN: Card type cannot be determined.

    """
    CREDIT = 'CREDIT'

    DEBIT = 'DEBIT'

    PREPAID = 'PREPAID'

    STORE = 'STORE'

    UNKNOWN = 'UNKNOWN'

