# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class RefundStatus(object):

    """Implementation of the 'Refund Status' enum.

    The status of the refund.

    Attributes:
        CANCELLED: The refund was cancelled.
        FAILED: The refund could not be processed.
        PENDING: The refund is pending. For more information, see
            status_details.reason.
        COMPLETED: The funds for this transaction were debited to the
            customer's account.

    """
    CANCELLED = 'CANCELLED'

    FAILED = 'FAILED'

    PENDING = 'PENDING'

    COMPLETED = 'COMPLETED'

