# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class CaptureType(object):

    """Implementation of the 'Capture Type' enum.

    The type of capture.

    Attributes:
        OUTSTANDING_BALANCE: The outstanding balance that the subscriber must
            clear.

    """
    OUTSTANDING_BALANCE = 'OUTSTANDING_BALANCE'

