# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class CallbackEvents(object):

    """Implementation of the 'Callback Events' enum.

    CallBack event.

    Attributes:
        SHIPPING_ADDRESS: When Buyer changes or selects the shipping address
            on the PayPal/Venmo buyer approval flow , PayPal/Venmo will call
            merchant with the callback URL to update order totals.
        SHIPPING_OPTIONS: When Buyer changes or selects the shipping options
            on the PayPal/Venmo buyer approval flow , PayPal/Venmo will call
            merchant with the callback URL to update order totals.

    """
    SHIPPING_ADDRESS = 'SHIPPING_ADDRESS'

    SHIPPING_OPTIONS = 'SHIPPING_OPTIONS'

