# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class UpcType(object):

    """Implementation of the 'UPC Type' enum.

    The Universal Product Code type.

    Attributes:
        UPC_A: The enum member of type str.
        UPC_B: The enum member of type str.
        UPC_C: The enum member of type str.
        UPC_D: The enum member of type str.
        UPC_E: The enum member of type str.
        UPC_2: The enum member of type str.
        UPC_5: The enum member of type str.

    """
    UPC_A = 'UPC-A'

    UPC_B = 'UPC-B'

    UPC_C = 'UPC-C'

    UPC_D = 'UPC-D'

    UPC_E = 'UPC-E'

    UPC_2 = 'UPC-2'

    UPC_5 = 'UPC-5'

