# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class VaultUserAction(object):

    """Implementation of the 'Vault User Action' enum.

    User Action on action to be performed after a successful payer approval.

    Attributes:
        SETUP_NOW: After you redirect the customer to the PayPal payment page,
            a Setup Now button appears. Use this option when no additional
            inputs are needed from merchant site and to create the billing
            agreement immediately when the customer clicks Setup Now.
        CONTINUE: After you redirect the customer to the PayPal payment page,
            a Continue button appears. Use this option when you want to
            redirect the customer from the completed payment page to the
            merchant site for additional inputs without immediately creating
            the billing agreement.

    """
    SETUP_NOW = 'SETUP_NOW'

    CONTINUE = 'CONTINUE'

