# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class IntervalUnit(object):

    """Implementation of the 'Interval Unit' enum.

    The interval at which the subscription is charged or billed.

    Attributes:
        DAY: A daily billing cycle.
        WEEK: A weekly billing cycle.
        MONTH: A monthly billing cycle.
        YEAR: A yearly billing cycle.

    """
    DAY = 'DAY'

    WEEK = 'WEEK'

    MONTH = 'MONTH'

    YEAR = 'YEAR'

