# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class ApplicationContextUserAction(object):

    """Implementation of the 'Application Context User Action' enum.

    Configures the label name to `Continue` or `Subscribe Now` for
    subscription consent experience.

    Attributes:
        CONTINUE: After you redirect the customer to the PayPal subscription
            consent page, a Continue button appears. Use this option when you
            want to control the activation of the subscription and do not want
            PayPal to activate the subscription.
        SUBSCRIBE_NOW: After you redirect the customer to the PayPal
            subscription consent page, a Subscribe Now button appears. Use
            this option when you want PayPal to activate the subscription.

    """
    CONTINUE = 'CONTINUE'

    SUBSCRIBE_NOW = 'SUBSCRIBE_NOW'

