# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class SubscriptionPlanStatus(object):

    """Implementation of the 'Subscription Plan Status' enum.

    The plan status.

    Attributes:
        CREATED: The plan was created. You cannot create subscriptions for a
            plan in this state.
        INACTIVE: The plan is inactive.
        ACTIVE: The plan is active. You can only create subscriptions for a
            plan in this state.

    """
    CREATED = 'CREATED'

    INACTIVE = 'INACTIVE'

    ACTIVE = 'ACTIVE'

